# Changelog

<!--next-version-placeholder-->

## v1.4.3 (2021-04-08)
### Fix
* **optimizr:** Move __version__ ([`0683762`](https://github.com/joeriddles/optimizr/commit/06837625c11fd463fc1f7772c86e4954dfff4384))
* **optimizr:** Move __version__ ([`c7dcfed`](https://github.com/joeriddles/optimizr/commit/c7dcfedecb1125b1b6405f5907c43f388b9264f2))

## v1.4.3 (2021-04-08)
### Fix
* **optimizr:** Move __version__ ([`c7dcfed`](https://github.com/joeriddles/optimizr/commit/c7dcfedecb1125b1b6405f5907c43f388b9264f2))

## v1.4.2 (2021-04-08)
### Fix
* **optimizr:** Fix setup ([`753f65e`](https://github.com/joeriddles/optimizr/commit/753f65e4218a5848a0496525f72c7ceeddcfe389))

## v1.4.1 (2021-04-08)
### Fix
* **optimizr:** Remove version from setup.cfg ([`f63b13b`](https://github.com/joeriddles/optimizr/commit/f63b13bac2739f23e4f57306fc032586f822c60f))

## v1.4.0 (2021-04-08)


## v1.3.0 (2021-04-08)
### Feature
* **optimizr:** Bump semver ([`6b87acd`](https://github.com/joeriddles/optimizr/commit/6b87acd25ceef559748d1e29926a490487b903ad))

## v1.2.0 (2021-04-08)
### Feature
* **optimizr:** Update semver ([`6418afa`](https://github.com/joeriddles/optimizr/commit/6418afa26ecad105f5daabf49ad087e37e208fe1))

### Fix
* **optimizr:** Bump semver ([`6b23888`](https://github.com/joeriddles/optimizr/commit/6b23888ed280ecc66ccc3610f3f6858d6539bf36))
* **optimizr:** Fix setup.cfg ([`bc08d49`](https://github.com/joeriddles/optimizr/commit/bc08d49b5572edb75b1f4a1b4447655246c52942))
* **1.0.11:** Trying to get semantic_release to work ([`52c2e3f`](https://github.com/joeriddles/optimizr/commit/52c2e3f0935871bdf27d0d26b59f36c0a5d0c6e9))

## v0.1.2 (2021-04-08)
### Fix
* **optimizr:** Bump semver ([`6b23888`](https://github.com/joeriddles/optimizr/commit/6b23888ed280ecc66ccc3610f3f6858d6539bf36))

## v0.1.1 (2021-04-08)
### Fix
* **optimizr:** Fix setup.cfg ([`bc08d49`](https://github.com/joeriddles/optimizr/commit/bc08d49b5572edb75b1f4a1b4447655246c52942))

## v0.1.0 (2021-04-08)
### Feature
* **optimizr:** Update semver ([`6418afa`](https://github.com/joeriddles/optimizr/commit/6418afa26ecad105f5daabf49ad087e37e208fe1))

## v0.0.1 (2021-04-08)
### Fix
* **1.0.11:** Trying to get semantic_release to work ([`52c2e3f`](https://github.com/joeriddles/optimizr/commit/52c2e3f0935871bdf27d0d26b59f36c0a5d0c6e9))
